"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const zos_files_for_zowe_sdk_1 = require("@zowe/zos-files-for-zowe-sdk");
const ZosFilesBase_handler_1 = require("../../ZosFilesBase.handler");
/**
 * Handler to view a data set's content
 * @export
 */
class DatasetHandler extends ZosFilesBase_handler_1.ZosFilesBaseHandler {
    processWithSession(commandParameters, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const task = {
                percentComplete: 0,
                statusMessage: "Retrieving first dataset",
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            // RETRIEVING THE FIRST DATA-SET
            commandParameters.response.progress.startBar({ task });
            const dsContentBuf1 = yield zos_files_for_zowe_sdk_1.Get.dataSet(session, commandParameters.arguments.dataSetName1, {
                binary: commandParameters.arguments.binary,
                encoding: commandParameters.arguments.encoding,
                record: commandParameters.arguments.record,
                volume: commandParameters.arguments.volumeSerial,
                responseTimeout: commandParameters.arguments.responseTimeout,
                task: task
            });
            commandParameters.response.progress.endBar();
            // RETRIEVING THE DATA-SET TO COMPARE
            task.statusMessage = "Retrieving second dataset";
            commandParameters.response.progress.startBar({ task });
            let binary2 = commandParameters.arguments.binary2;
            let encoding2 = commandParameters.arguments.encoding2;
            let record2 = commandParameters.arguments.record2;
            const volumeSerial2 = commandParameters.arguments.volumeSerial2;
            if (binary2 == undefined) {
                binary2 = commandParameters.arguments.binary;
            }
            if (encoding2 == undefined) {
                encoding2 = commandParameters.arguments.encoding;
            }
            if (record2 == undefined) {
                record2 = commandParameters.arguments.record;
            }
            const dsContentBuf2 = yield zos_files_for_zowe_sdk_1.Get.dataSet(session, commandParameters.arguments.dataSetName2, {
                binary: binary2,
                encoding: encoding2,
                record: record2,
                volume: volumeSerial2,
                responseTimeout: commandParameters.arguments.responseTimeout,
                task: task
            });
            commandParameters.response.progress.endBar();
            //CHECKING IF NEEDING TO SPLIT CONTENT STRINGS FOR SEQNUM OPTION
            let dsContentString1 = "";
            let dsContentString2 = "";
            const seqnumlen = 8;
            if (commandParameters.arguments.seqnum === false) {
                dsContentString1 = dsContentBuf1.toString().split("\n")
                    .map((line) => line.slice(0, -seqnumlen))
                    .join("\n");
                dsContentString2 = dsContentBuf2.toString().split("\n")
                    .map((line) => line.slice(0, -seqnumlen))
                    .join("\n");
            }
            else {
                dsContentString1 = dsContentBuf1.toString();
                dsContentString2 = dsContentBuf2.toString();
            }
            // CHECK TO OPEN UP DIFF IN BROWSER WINDOW
            if (commandParameters.arguments.browserView) {
                yield imperative_1.DiffUtils.openDiffInbrowser(dsContentString1, dsContentString2);
                return {
                    success: true,
                    commandResponse: "Launching data-sets diffs in browser...",
                    apiResponse: {}
                };
            }
            // RETURNING DIFF
            const jsonDiff = yield imperative_1.DiffUtils.getDiffString(dsContentString1, dsContentString2, {
                outputFormat: 'terminal',
                contextLinesArg: commandParameters.arguments.contextLines
            });
            return {
                success: true,
                commandResponse: jsonDiff,
                apiResponse: {}
            };
        });
    }
}
exports.default = DatasetHandler;
//# sourceMappingURL=Dataset.handler.js.map